@@ -1,6 +1,7 @@
 use crate::{
     base::{APIResponse, BaseClient},
     shared::MetadataFindInput,
+    Tz, Weekday,
 };
 use nettu_scheduler_api_structs::*;
 use nettu_scheduler_domain::{
@@ -17,8 +18,8 @@ pub struct CalendarClient {
 
 pub struct CreateCalendarInput {
     pub user_id: ID,
-    pub timezone: String,
-    pub week_start: isize,
+    pub timezone: Tz,
+    pub week_start: Weekday,
     pub metadata: Option<Metadata>,
 }
 
@@ -36,27 +37,29 @@ pub struct StopCalendarSyncInput {
     pub provider: IntegrationProvider,
 }
 
-pub struct GetCalendarInput {
-    pub calendar_id: ID,
-}
-
 pub struct GetCalendarEventsInput {
     pub calendar_id: ID,
     pub start_ts: i64,
     pub end_ts: i64,
 }
 
-pub struct DeleteCalendarInput {
-    pub calendar_id: ID,
-}
-
 pub struct UpdateCalendarInput {
     pub calendar_id: ID,
-    pub week_start: Option<isize>,
-    pub timezone: Option<String>,
+    pub week_start: Option<Weekday>,
+    pub timezone: Option<Tz>,
     pub metadata: Option<Metadata>,
 }
 
+pub struct GetGoogleCalendars {
+    pub user_id: ID,
+    pub min_access_role: GoogleCalendarAccessRole,
+}
+
+pub struct GetOutlookCalendars {
+    pub user_id: ID,
+    pub min_access_role: OutlookCalendarAccessRole,
+}
+
 impl CalendarClient {
     pub(crate) fn new(base: Arc<BaseClient>) -> Self {
         Self { base }
@@ -67,7 +70,7 @@ impl CalendarClient {
         input: UpdateCalendarInput,
     ) -> APIResponse<update_calendar::APIResponse> {
         let settings = update_calendar::CalendarSettings {
-            timezone: input.timezone.clone(),
+            timezone: input.timezone,
             week_start: input.week_start,
         };
         let body = update_calendar::RequestBody {
@@ -83,24 +86,15 @@ impl CalendarClient {
             .await
     }
 
-    pub async fn delete(
-        &self,
-        input: DeleteCalendarInput,
-    ) -> APIResponse<delete_calendar::APIResponse> {
+    pub async fn delete(&self, calendar_id: ID) -> APIResponse<delete_calendar::APIResponse> {
         self.base
-            .delete(
-                format!("user/calendar/{}", input.calendar_id),
-                StatusCode::OK,
-            )
+            .delete(format!("user/calendar/{}", calendar_id), StatusCode::OK)
             .await
     }
 
-    pub async fn get(&self, input: GetCalendarInput) -> APIResponse<get_calendar::APIResponse> {
+    pub async fn get(&self, calendar_id: ID) -> APIResponse<get_calendar::APIResponse> {
         self.base
-            .get(
-                format!("user/calendar/{}", input.calendar_id),
-                StatusCode::OK,
-            )
+            .get(format!("user/calendar/{}", calendar_id), StatusCode::OK)
             .await
     }
 
@@ -136,7 +130,7 @@ impl CalendarClient {
         input: CreateCalendarInput,
     ) -> APIResponse<create_calendar::APIResponse> {
         let body = create_calendar::RequestBody {
-            timezone: input.timezone.clone(),
+            timezone: input.timezone,
             week_start: input.week_start,
             metadata: input.metadata,
         };
@@ -187,14 +181,13 @@ impl CalendarClient {
 
     pub async fn get_google(
         &self,
-        user_id: ID,
-        min_access_role: GoogleCalendarAccessRole,
+        input: GetGoogleCalendars,
     ) -> APIResponse<get_google_calendars::APIResponse> {
         self.base
             .get(
                 format!(
                     "user/{:?}/calendar/provider/google?minAccessRole={:?}",
-                    user_id, min_access_role
+                    input.user_id, input.min_access_role
                 ),
                 StatusCode::OK,
             )
@@ -203,14 +196,13 @@ impl CalendarClient {
 
     pub async fn get_outlook(
         &self,
-        user_id: ID,
-        min_access_role: OutlookCalendarAccessRole,
+        input: GetOutlookCalendars,
     ) -> APIResponse<get_outlook_calendars::APIResponse> {
         self.base
             .get(
                 format!(
                     "user/{:?}/calendar/provider/outlook?minAccessRole={:?}",
-                    user_id, min_access_role
+                    input.user_id, input.min_access_role
                 ),
                 StatusCode::OK,
             )
